MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / sqrtKernel

Function sqrtKernel

XM/include/Dense/sqrt.h:9–14  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

7
8template <typename T>
9__global__ void sqrtKernel(T* d_out, T* d_in, size_l size) {
10 size_l idx = threadIdx.x + blockIdx.x * blockDim.x;
11 if (idx < size) {
12 d_out[idx] = sqrt(d_in[idx]);
13 }
14}
15
16// take deviceDnTen as input
17template <typename T>

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected